@@ -1,23 +1,31 @@
 use Renard::Incunabula::Common::Setup;
 package Intertangle::API::Gtk3::GdkQuartz;
 # ABSTRACT: Load the GdkQuartz library
-$Intertangle::API::Gtk3::GdkQuartz::VERSION = '0.005';
+$Intertangle::API::Gtk3::GdkQuartz::VERSION = '0.006';
 use FFI::Platypus;
 use FFI::CheckLib 0.06;
 
+my $ffi;
 sub import {
-	# Need to attach the `gdk_quartz_window_get_nsview` function.
-	my $ffi = FFI::Platypus->new;
+	local $SIG{__WARN__} = sub { warn $_[0] unless $_[0] =~ /Subroutine \Q@{[ __PACKAGE__ ]}\E.* redefined/ };
 
-	$ffi->lib(find_lib_or_die lib => 'gdk-3');
-	# NSView * gdk_quartz_window_get_nsview (GdkWindow *window)
-	$ffi->attach( gdk_quartz_window_get_nsview => [ 'opaque' ], 'opaque', sub {
-		my ($xs, $gdk_window) = @_;
-		Gtk3::Gdk::threads_enter();
-		my $view = $xs->( Glib::Object::get_pointer($gdk_window) );
-		Gtk3::Gdk::threads_leave();
-		return $view;
-	});
+	# Need to attach the `gdk_quartz_window_get_nsview` function.
+	$ffi ||= do {
+		my $ffi = FFI::Platypus->new;
+
+
+		$ffi->lib(find_lib_or_die lib => 'gdk-3');
+		# NSView * gdk_quartz_window_get_nsview (GdkWindow *window)
+		$ffi->attach( gdk_quartz_window_get_nsview => [ 'opaque' ], 'opaque', sub {
+			my ($xs, $gdk_window) = @_;
+			Gtk3::Gdk::threads_enter();
+			my $view = $xs->( Glib::Object::get_pointer($gdk_window) );
+			Gtk3::Gdk::threads_leave();
+			return $view;
+		});
+
+		$ffi;
+	};
 }
 
 1;
@@ -34,7 +42,7 @@ Intertangle::API::Gtk3::GdkQuartz - Load the GdkQuartz library
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 AUTHOR
 
